<?php


namespace Steffospieler\DiscordWebhook;

require_once __DIR__ . '/Field.php';
require_once __DIR__ . '/Footer.php';
require_once __DIR__ . '/Author.php';

/**
 * Class Embed
 */
class Embed {
    public string $title;
    public ?string $description;
    public ?string $url;
    public mixed $timestamp;
    public ?string $color = "";
    public ?Footer $footer = null;
    public ?string $image_url = null;
    public ?string $thumbnail_url = null;
    public ?Author $author = null;
    private array $fields = [];

    public function __construct($title, $description = null, $color = null) {
        $this->title = $title;
        $this->description = $description;
        $this->color = $color;
    }

    public function add_field(Field $field) : void {
        $this->fields[] = $field;
    }

    public function get_field() : array {
        return $this->fields;
    }

    public function to_array() : array {
        $array = [];

        $array["title"] = $this->title;
        $array["type"] = "rich";
        if (isset($this->description)) {
            $array["description"] = $this->description;
        }
        if (isset($this->url)) {
            $array["url"] = $this->url;
        }
        if (isset($this->timestamp)) {
            $array["timestamp"] = $this->timestamp;
        }
        $array["color"] = hexdec($this->color);
        if (isset($this->footer)) {
            $array["footer"] = $this->footer->to_array();
        }
        if (isset($this->image_url)) {
            $array["image"]["url"] = $this->image_url;
        }
        if (isset($this->thumbnail_url)) {
            $array["thumbnail"]["url"] = $this->thumbnail_url;
        }
        if (isset($this->author)) {
            $array["author"] = $this->author->to_array();
        }
        $array["fields"] = [];

        foreach ($this->fields as $field) {
            $array["fields"][] = $field->to_array();
        }

        return $array;
    }
}