<?php


namespace Steffospieler\DiscordWebhook;

use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;

require_once __DIR__ . '/Embed.php';

/**
 * Class Message
 */
class Message {
    public ?string $content;
    public ?string $username = null;
    public ?string $avatar_url = null;
    public bool $tts = false;
    private array $embeds = [];

    public function __construct($content = null) {
        $this->content = $content;
    }

    public function add_embed(Embed $embed) : void {
        $this->embeds[] = $embed;
    }

    public function get_embeds() : array {
        return $this->embeds;
    }

    /**
     * @throws GuzzleException
     */
    public function send($webhook) : void {
        $client = new Client();
        $client->request("POST", $webhook, [
            'headers' => ['Content-type' => 'application/json'],
            'body' => json_encode($this->to_array(), JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE)
        ]);
    }

    private function to_array() : array {
        $array = [];

        if (isset($this->content)) {
            $array["content"] = $this->content;
        }
        if (isset($this->username)) {
            $array["username"] = $this->username;
        }
        if (isset($this->avatar_url)) {
            $array["avatar_url"] = $this->avatar_url;
        }
        $array["tts"] = $this->tts;
        $array["embeds"] = [];

        foreach ($this->embeds as $embed) {
            $array["embeds"][] = $embed->to_array();
        }

        return $array;
    }
}